# tdub

[![Build Status](https://dev.azure.com/ddavis0485/tdub/_apis/build/status/douglasdavis.tdub?branchName=master)](https://dev.azure.com/ddavis0485/tdub/_build/latest?definitionId=3&branchName=master)
[![Documentation Status](https://readthedocs.org/projects/tdub/badge/?version=latest)](https://tdub.readthedocs.io/)
[![PyPI](https://img.shields.io/pypi/v/tdub)](https://pypi.org/project/tdub/)
[![Python Version](https://img.shields.io/pypi/pyversions/tdub)](https://pypi.org/project/tdub/)
